@@ -20,6 +20,8 @@
 #
 
 import sys
+import gi
+gi.require_version('NM', '1.0')
 from gi.repository import GLib, NM
 
 #
