@@ -32,6 +32,7 @@
 #include "nm-device-private.h"
 #include "nm-dbus-glib-types.h"
 #include "nm-modem-enum-types.h"
+#include "nm-route-manager.h"
 
 G_DEFINE_TYPE (NMModem, nm_modem, G_TYPE_OBJECT)
 
@@ -615,7 +616,7 @@ nm_modem_ip4_pre_commit (NMModem *modem,
 
 		g_assert (address);
 		if (address->plen == 32)
-			nm_platform_link_set_noarp (nm_device_get_ip_ifindex (device));
+			nm_platform_link_set_noarp (NM_PLATFORM_GET, nm_device_get_ip_ifindex (device));
 	}
 }
 
@@ -912,9 +913,9 @@ deactivate_cleanup (NMModem *self, NMDevice *device)
 		    priv->ip6_method == NM_MODEM_IP_METHOD_AUTO) {
 			ifindex = nm_device_get_ip_ifindex (device);
 			if (ifindex > 0) {
-				nm_platform_route_flush (ifindex);
-				nm_platform_address_flush (ifindex);
-				nm_platform_link_set_down (ifindex);
+				nm_route_manager_route_flush (nm_route_manager_get (), ifindex);
+				nm_platform_address_flush (NM_PLATFORM_GET, ifindex);
+				nm_platform_link_set_down (NM_PLATFORM_GET, ifindex);
 			}
 		}
 	}
