@@ -184,6 +184,7 @@ static void client_state_changed (NMDhcpClient *client,
                                   NMDhcpState state,
                                   GObject *ip_config,
                                   GHashTable *options,
+                                  const char *event_id,
                                   NMDhcpManager *self);
 
 static void
@@ -204,6 +205,7 @@ client_state_changed (NMDhcpClient *client,
                       NMDhcpState state,
                       GObject *ip_config,
                       GHashTable *options,
+                      const char *event_id,
                       NMDhcpManager *self)
 {
 	if (state >= NM_DHCP_STATE_TIMEOUT)
@@ -371,16 +373,7 @@ nm_dhcp_manager_get_lease_ip_configs (NMDhcpManager *self,
 
 /***************************************************/
 
-NMDhcpManager *
-nm_dhcp_manager_get (void)
-{
-	static NMDhcpManager *singleton = NULL;
-
-	if (G_UNLIKELY (singleton == NULL))
-		singleton = g_object_new (NM_TYPE_DHCP_MANAGER, NULL);
-	g_assert (singleton);
-	return singleton;
-}
+NM_DEFINE_SINGLETON_GETTER (NMDhcpManager, nm_dhcp_manager_get, NM_TYPE_DHCP_MANAGER);
 
 static void
 nm_dhcp_manager_init (NMDhcpManager *self)
