@@ -35,6 +35,7 @@
 #endif
 #include <unistd.h>
 #include <sys/syscall.h>
+#include <time.h>
 
 #include "nm-logging.h"
 
@@ -43,6 +44,12 @@
 #define BPF_XOR 0xa0
 #endif
 
+#ifndef CLOCK_BOOTTIME
+#define CLOCK_BOOTTIME 7
+#endif
+
+/*****************************************************************************/
+
 static inline guint32
 _slog_level_to_nm (int slevel)
 {
@@ -75,18 +82,20 @@ G_STMT_START { \
 
 #define log_assert_failed(e, file, line, func) \
 G_STMT_START { \
-	nm_log_err (LOGD_DHCP, #file ":" #line "(" #func "): assertion failed: " # e); \
+	nm_log_err (LOGD_DHCP, "%s:%d (%s): assertion failed: %s", (""file), (line), (func), G_STRINGIFY (e)); \
 	g_assert (FALSE); \
 } G_STMT_END
 
 #define log_assert_failed_unreachable(t, file, line, func) \
 G_STMT_START { \
-	nm_log_err (LOGD_DHCP, #file ":" #line "(" #func "): assert unreachable: " # t); \
+	nm_log_err (LOGD_DHCP, "%s:%d (%s): assert unreachable: %s", (""file), (line), (func), G_STRINGIFY (t)); \
 	g_assert_not_reached (); \
 } G_STMT_END
 
 #define log_assert_failed_return(e, file, line, func) \
-	nm_log_err (LOGD_DHCP, #file ":" #line "(" #func "): assert return: " # e); \
+G_STMT_START { \
+	nm_log_err (LOGD_DHCP, "%s:%d (%s): assert return: %s", (""file), (line), (func), G_STRINGIFY (e)); \
+} G_STMT_END
 
 #define log_oom nm_log_err(LOGD_CORE, "%s:%s/%s: OOM", __FILE__, __LINE__, __func__)
 
