@@ -46,12 +46,9 @@
 #include "main-utils.h"
 #include "nm-manager.h"
 #include "nm-linux-platform.h"
-#include "nm-dns-manager.h"
 #include "nm-dbus-manager.h"
-#include "nm-supplicant-manager.h"
+#include "nm-device.h"
 #include "nm-dhcp-manager.h"
-#include "nm-firewall-manager.h"
-#include "nm-vpn-manager.h"
 #include "nm-logging.h"
 #include "nm-config.h"
 #include "nm-session-monitor.h"
@@ -293,11 +290,6 @@ main (int argc, char *argv[])
 	gboolean wifi_enabled = TRUE, net_enabled = TRUE, wwan_enabled = TRUE, wimax_enabled = TRUE;
 	gboolean success = FALSE;
 	NMManager *manager = NULL;
-	gs_unref_object NMVpnManager *vpn_manager = NULL;
-	gs_unref_object NMDnsManager *dns_mgr = NULL;
-	gs_unref_object NMSupplicantManager *sup_mgr = NULL;
-	gs_unref_object NMDhcpManager *dhcp_mgr = NULL;
-	gs_unref_object NMFirewallManager *fw_mgr = NULL;
 	gs_unref_object NMSettings *settings = NULL;
 	gs_unref_object NMConfig *config = NULL;
 	gs_unref_object NMSessionMonitor *session_monitor = NULL;
@@ -483,16 +475,6 @@ main (int argc, char *argv[])
 
 	nm_auth_manager_setup (nm_config_get_auth_polkit (config));
 
-	vpn_manager = nm_vpn_manager_get ();
-	g_assert (vpn_manager != NULL);
-
-	dns_mgr = nm_dns_manager_get ();
-	g_assert (dns_mgr != NULL);
-
-	/* Initialize DHCP manager */
-	dhcp_mgr = nm_dhcp_manager_get ();
-	g_assert (dhcp_mgr != NULL);
-
 	nm_dispatcher_init ();
 
 	settings = nm_settings_new (&error);
@@ -509,14 +491,6 @@ main (int argc, char *argv[])
 	                          wwan_enabled,
 	                          wimax_enabled);
 
-	/* Initialize the supplicant manager */
-	sup_mgr = nm_supplicant_manager_get ();
-	g_assert (sup_mgr != NULL);
-
-	/* Initialize Firewall manager */
-	fw_mgr = nm_firewall_manager_get ();
-	g_assert (fw_mgr != NULL);
-
 	/* Initialize session monitor */
 	session_monitor = nm_session_monitor_get ();
 	g_assert (session_monitor != NULL);
