@@ -18,28 +18,25 @@
  * Copyright (C) 2010 - 2011 Red Hat, Inc.
  */
 
-#ifndef NM_SECRET_AGENT_H
-#define NM_SECRET_AGENT_H
+#ifndef __NETWORKMANAGER_SECRET_AGENT_H__
+#define __NETWORKMANAGER_SECRET_AGENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <dbus/dbus-glib.h>
-#include <dbus/dbus-glib-lowlevel.h>
 
 #include <nm-connection.h>
-#include "nm-dbus-manager.h"
-#include "nm-settings-flags.h"
+#include "nm-types.h"
 
 #define NM_TYPE_SECRET_AGENT            (nm_secret_agent_get_type ())
 #define NM_SECRET_AGENT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NM_TYPE_SECRET_AGENT, NMSecretAgent))
 #define NM_SECRET_AGENT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NM_TYPE_SECRET_AGENT, NMSecretAgentClass))
 #define NM_IS_SECRET_AGENT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NM_TYPE_SECRET_AGENT))
-#define NM_IS_SECRET_AGENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), NM_TYPE_SECRET_AGENT))
+#define NM_IS_SECRET_AGENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NM_TYPE_SECRET_AGENT))
 #define NM_SECRET_AGENT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NM_TYPE_SECRET_AGENT, NMSecretAgentClass))
 
-typedef struct {
+struct _NMSecretAgent {
 	GObject parent;
-} NMSecretAgent;
+};
 
 typedef struct {
 	GObjectClass parent;
@@ -47,10 +44,10 @@ typedef struct {
 
 GType nm_secret_agent_get_type (void);
 
-NMSecretAgent *nm_secret_agent_new (NMDBusManager *dbus_mgr,
-                                    const char *owner,
+NMSecretAgent *nm_secret_agent_new (DBusGMethodInvocation *context,
+                                    NMAuthSubject *subject,
                                     const char *identifier,
-                                    uid_t owner_uid);
+                                    NMSecretAgentCapabilities capabilities);
 
 const char *nm_secret_agent_get_description (NMSecretAgent *agent);
 
@@ -58,12 +55,18 @@ const char *nm_secret_agent_get_dbus_owner (NMSecretAgent *agent);
 
 const char *nm_secret_agent_get_identifier (NMSecretAgent *agent);
 
-uid_t       nm_secret_agent_get_owner_uid  (NMSecretAgent *agent);
+gulong      nm_secret_agent_get_owner_uid  (NMSecretAgent *agent);
 
 const char *nm_secret_agent_get_owner_username (NMSecretAgent *agent);
 
+gulong      nm_secret_agent_get_pid        (NMSecretAgent *agent);
+
+NMSecretAgentCapabilities nm_secret_agent_get_capabilities (NMSecretAgent *agent);
+
 guint32     nm_secret_agent_get_hash       (NMSecretAgent *agent);
 
+NMAuthSubject *nm_secret_agent_get_subject (NMSecretAgent *agent);
+
 void        nm_secret_agent_add_permission (NMSecretAgent *agent,
                                             const char *permission,
                                             gboolean allowed);
@@ -80,8 +83,8 @@ typedef void (*NMSecretAgentCallback) (NMSecretAgent *agent,
 gconstpointer nm_secret_agent_get_secrets  (NMSecretAgent *agent,
                                             NMConnection *connection,
                                             const char *setting_name,
-                                            const char *hint,
-                                            NMSettingsGetSecretsFlags flags,
+                                            const char **hints,
+                                            NMSecretAgentGetSecretsFlags flags,
                                             NMSecretAgentCallback callback,
                                             gpointer callback_data);
 
@@ -98,4 +101,4 @@ gconstpointer nm_secret_agent_delete_secrets (NMSecretAgent *agent,
                                               NMSecretAgentCallback callback,
                                               gpointer callback_data);
 
-#endif /* NM_SECRET_AGENT_H */
+#endif /* __NETWORKMANAGER_SECRET_AGENT_H__ */
