@@ -321,6 +321,27 @@ test_nm_ip6_config_addresses_sort (void)
 	g_object_unref (config);
 }
 
+static void
+test_strip_search_trailing_dot (void)
+{
+	NMIP6Config *config;
+
+	config = nm_ip6_config_new ();
+
+	nm_ip6_config_add_search (config, ".");
+	nm_ip6_config_add_search (config, "foo");
+	nm_ip6_config_add_search (config, "bar.");
+	nm_ip6_config_add_search (config, "baz.com");
+	nm_ip6_config_add_search (config, "baz.com.");
+
+	g_assert_cmpuint (nm_ip6_config_get_num_searches (config), ==, 3);
+	g_assert_cmpstr (nm_ip6_config_get_search (config, 0), ==, "foo");
+	g_assert_cmpstr (nm_ip6_config_get_search (config, 1), ==, "bar");
+	g_assert_cmpstr (nm_ip6_config_get_search (config, 2), ==, "baz.com");
+
+	g_object_unref (config);
+}
+
 /*******************************************/
 
 NMTST_DEFINE();
@@ -335,6 +356,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/ip6-config/add-address-with-source", test_add_address_with_source);
 	g_test_add_func ("/ip6-config/add-route-with-source", test_add_route_with_source);
 	g_test_add_func ("/ip6-config/test_nm_ip6_config_addresses_sort", test_nm_ip6_config_addresses_sort);
+	g_test_add_func ("/ip6-config/strip-search-trailing-dot", test_strip_search_trailing_dot);
 
 	return g_test_run ();
 }
